Index: runtime/bin/process.dart |
diff --git a/runtime/bin/process.dart b/runtime/bin/process.dart |
index 74b3ff51592389bc8e166122027a5424024c1a15..181f6c6e7f6f0bbfa1e0a43a071bc7c8d7f908e8 100644 |
--- a/runtime/bin/process.dart |
+++ b/runtime/bin/process.dart |
@@ -9,17 +9,17 @@ |
interface Process default _Process { |
/** |
* Creates a new process object and starts a process running the |
* [executable] with the specified [arguments]. When the process has been |
* successfully started the [startHandler] is called. If the process fails |
* to start the [errorHandler] is called. |
* |
* An optional [workingDirectory] can be passed to specify where the process |
* is run from. Note that the change of directory occurs before executing |
* the process on some platforms, which may have impact when using relative |
* paths for [executable] and [arguments]. |
* |
* No data can be written to the process stdin and the process cannot be |
* closed nor killed before the [startHandler] has been invoked. |
*/ |
Process.start(String executable, |
List<String> arguments, |
@@ -44,32 +44,32 @@ interface Process default _Process { |
* Set the start handler which gets invoked when the process is |
* successfully started. |
*/ |
- void set startHandler(void callback()); |
+ void set onStart(void callback()); |
/** |
* Sets an exit handler which gets invoked when the process terminates. |
*/ |
- void set exitHandler(void callback(int exitCode)); |
+ void set onExit(void callback(int exitCode)); |
/** |
* Set an error handler which gets invoked if an operation on the process |
* fails. |
*/ |
- void set errorHandler(void callback(ProcessException error)); |
+ void set onError(void callback(ProcessException error)); |
/** |
* Kills the process. When the process terminates as a result of calling |
* [kill] the [exitHandler] is called. If the kill operation fails, the |
* [errorHandler] is called. |
*/ |
void kill(); |
/** |
* Terminates the streams of a process. [close] most be called on a process |
* to free the system resources associated with it. Usually, close should be |
* called in the [exitHandler]. Once a process has been closed it can no |
* longer be killed and the [exitHandler] is detached so the application is |
* not notified of process termination. |
*/ |
void close(); |
} |
@@ -9,17 +9,17 @@ |
/** |
* Creates a new process object and starts a process running the |
- * [executable] with the specified [arguments]. When the process has been |
- * successfully started the [startHandler] is called. If the process fails |
- * to start the [errorHandler] is called. |
+ * [executable] with the specified [arguments]. When the process has |
+ * been successfully started [onStart] is called. If the process |
+ * fails to start [onError] is called. |
* |
* An optional [workingDirectory] can be passed to specify where the process |
@@ -9,17 +9,17 @@ |
* paths for [executable] and [arguments]. |
* |
- * No data can be written to the process stdin and the process cannot be |
- * closed nor killed before the [startHandler] has been invoked. |
+ * No data can be written to the process stdin and the process |
+ * cannot be closed nor killed before [onStart] has been invoked. |
*/ |
Process.start(String executable, |
@@ -44,32 +44,32 @@ interface Process default _Process { |
/** |
- * Kills the process. When the process terminates as a result of calling |
- * [kill] the [exitHandler] is called. If the kill operation fails, the |
- * [errorHandler] is called. |
+ * Kills the process. When the process terminates as a result of |
+ * calling [kill] [onExit] is called. If the kill operation fails, |
+ * [onError] is called. |
*/ |
void kill(); |
@@ -44,32 +44,32 @@ interface Process default _Process { |
void kill(); |
/** |
- * Terminates the streams of a process. [close] most be called on a process |
- * to free the system resources associated with it. Usually, close should be |
- * called in the [exitHandler]. Once a process has been closed it can no |
- * longer be killed and the [exitHandler] is detached so the application is |
- * not notified of process termination. |
+ * Terminates the streams of a process. [close] most be called on a |
+ * process to free the system resources associated with it. Usually, |
+ * close should be called in [onExit]. Once a process has been |
+ * closed it can no longer be killed and [onExit] is detached so the |
+ * application is not notified of process termination. |
*/ |
void close(); |